#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_SCALAR_IF_ZERO_ELSE_ONE_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_SCALAR_IF_ZERO_ELSE_ONE_HPP_INCLUDED

#include <boost/simd/boolean/include/functions/scalar/if_zero_else_one.hpp>

#endif
